.. testsetup:: *

   from pwn import *

:mod:`pwnlib.encoders` --- Encoding Shellcode
===============================================

.. automodule:: pwnlib.encoders
   :members:

.. automodule:: pwnlib.encoders.encoder
   :members:


.. automodule:: pwnlib.encoders.amd64
   :members:

.. automodule:: pwnlib.encoders.arm
   :members:

.. automodule:: pwnlib.encoders.i386
   :members:

.. automodule:: pwnlib.encoders.i386.xor
   :members:
